@@ -34,7 +34,7 @@ def run(path, ignore=None, select=None, linters=DEFAULT_LINTERS, config=None,
     """
     errors = []
     params = dict(ignore=ignore, select=select)
-
+    code = None
     try:
         with open(path, 'rU') as f:
             code = f.read() + '\n\n'
@@ -66,13 +66,12 @@ def run(path, ignore=None, select=None, linters=DEFAULT_LINTERS, config=None,
 
     except IOError as e:
         errors.append(dict(
-            lnum=0, type='E', col=0, text=str(e)
-        ))
+            lnum=0, type='E', col=0, text=str(e), filename=path or ''))
 
     except SyntaxError as e:
         errors.append(dict(
             lnum=e.lineno or 0, type='E', col=e.offset or 0,
-            text=e.args[0] + ' [%s]' % lint
+            text=e.args[0] + ' [%s]' % lint, filename=path or ''
         ))
 
     except Exception:
@@ -80,7 +79,9 @@ def run(path, ignore=None, select=None, linters=DEFAULT_LINTERS, config=None,
         logging.debug(traceback.format_exc())
 
     errors = [er for er in errors if filter_errors(er, **params)]
-    errors = filter_skiplines(code, errors)
+
+    if code:
+        errors = filter_skiplines(code, errors)
 
     return sorted(errors, key=lambda x: x['lnum'])
 
