@@ -1,5 +1,4 @@
-""" Interfaces for code checking.
-"""
+""" Interfaces for code checking. """
 from __future__ import absolute_import, with_statement
 
 import _ast
@@ -101,9 +100,9 @@ def pylint(path, **meta):
 
     from .checkers.pylint.lint import Run
     from .checkers.pylint.reporters import BaseReporter
-    from .checkers.pylint.logilab.astng import MANAGER
+    from .checkers.pylint.astroid import MANAGER
 
-    MANAGER.astng_cache.clear()
+    MANAGER.astroid_cache.clear()
 
     class Reporter(BaseReporter):
 
